package com.goldenwater.slaj.eme.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.eme.mapper.BusiRegularEvaluMapper;
import com.goldenwater.slaj.eme.domain.BusiRegularEvalu;
import com.goldenwater.slaj.eme.service.IBusiRegularEvaluService;

/**
 * 应急预案定期评估 服务层实现
 */
@Service
public class BusiRegularEvaluServiceImpl implements IBusiRegularEvaluService {

    @Autowired
    private BusiRegularEvaluMapper busiRegularEvaluMapper;

    @Override
    public BusiRegularEvalu selectBusiRegularEvaluByGuid(String guid) {
        return busiRegularEvaluMapper.selectBusiRegularEvaluByGuid(guid);
    }

    @Override
    public List<BusiRegularEvalu> selectBusiRegularEvaluList(BusiRegularEvalu busiRegularEvalu) {
        return busiRegularEvaluMapper.selectBusiRegularEvaluList(busiRegularEvalu);
    }

    @Override
    public int insertBusiRegularEvalu(BusiRegularEvalu busiRegularEvalu) {
        return busiRegularEvaluMapper.insertBusiRegularEvalu(busiRegularEvalu);
    }

    @Override
    public int updateBusiRegularEvalu(BusiRegularEvalu busiRegularEvalu) {
        return busiRegularEvaluMapper.updateBusiRegularEvalu(busiRegularEvalu);
    }

    @Override
    public int deleteBusiRegularEvaluByGuid(String guid) {
        return busiRegularEvaluMapper.deleteBusiRegularEvaluByGuid(guid);
    }

    @Override
    public int deleteBusiRegularEvaluByGuids(String[] guids) {
        return busiRegularEvaluMapper.deleteBusiRegularEvaluByGuids(guids);
    }
}
